==========
Django-CSP
==========

Django-CSP adds Content-Security-Policy_ headers and a CSP report
processing facility to Django.

The code lives on GitHub_, where you can report Issues_. The full
documentation is available on ReadTheDocs_.

.. image:: https://travis-ci.org/mozilla/django-csp.png?branch=master
   :target: https://travis-ci.org/mozilla/django-csp

.. _Content-Security-Policy: http://www.w3.org/TR/CSP/
.. _GitHub: https://github.com/mozilla/django-csp
.. _Issues: https://github.com/mozilla/django-csp/issues
.. _ReadTheDocs: http://django-csp.readthedocs.org/
